@@ -1,6 +1,6 @@
 """KayPENTAX Disordered Voice Database Reader module"""
 
-__version__ = "0.3.0"
+__version__ = "0.3.1"
 
 import pandas as pd
 from os import path
@@ -253,9 +253,7 @@ class KPDVDB:
             or "DIAGNOSES" in filters
         )
 
-        test_dx = lambda x: (diagnoses_filter and any(diagnoses_filter(xi) for xi in x))
-
-        if incl_dx or test_dx:
+        if incl_dx or diagnoses_filter:
             df.insert(3, "DIAGNOSES", self._get_dx_series())
 
         # apply the filters to reduce the rows
@@ -279,9 +277,8 @@ class KPDVDB:
                     df = df[s == fcond]
 
         # if diagnosis screening function is given, further filter the rows
-        if test_dx:
-            s = df["DIAGNOSES"]
-            df = df[[test_dx(v) for v in s]]
+        if diagnoses_filter:
+            df = df[[diagnoses_filter(v) for v in df["DIAGNOSES"]]]
 
             if not incl_dx:
                 # if dx not requested, drop it
@@ -327,7 +324,7 @@ class KPDVDB:
         :return: list of NSP files and optionally
         :rtype: list(str) or tuple(list(str), pandas.DataFrame)
 
-        Valid values of `subset` argument
+        Valid values of `auxdata_fields` argument
         ---------------------------------
 
         * All columns of the database specified in EXCEL50/TEXT/README.TXT Section 3.1
@@ -428,7 +425,7 @@ class KPDVDB:
 
 
 
-        Valid values of `subset` argument
+        Valid values of `auxdata_fields` argument
         ---------------------------------
 
         * All columns of the database specified in EXCEL50/TEXT/README.TXT Section 3.1
